This function retrieves the data dictionary for the specified data directory.
spod_available_data_v2(
data_dir = spod_get_data_dir(),
check_local_files = FALSE,
use_s3 = TRUE,
force = FALSE,
quiet = FALSE
)A tibble with links, release dates of files in the data, dates of data coverage, local paths to files, and the download status.
character. The URL link to the data file.
POSIXct. The timestamp of when the file was published.
character. The file extension of the data file (e.g., 'tar', 'gz').
Date. The year and month of the data coverage, if available.
Date. The specific date of the data coverage, if available.
factor. Study category derived from the URL (e.g., 'basic', 'complete', 'routes').
factor. Data type category derived from the URL (e.g., 'number_of_trips', 'origin-destination', 'overnight_stays', 'data_quality', 'metadata').
factor. Temporal granularity category derived from the URL (e.g., 'day', 'month').
factor. Geographic zone classification derived from the URL (e.g., 'districts', 'municipalities', 'large_urban_areas').
character. The local file path where the data is (or going to be) stored.
logical. Indicator of whether the data file has been downloaded locally. This is only available if check_local_files is TRUE.
The directory where the data is stored. Defaults to the value returned by spod_get_data_dir().
Logical. Whether to check if the local files exist and get the file size. Defaults to FALSE.
Logical. If
TRUE, use Amazon S3 to get available data list, which does not require downloading the XML file and caching it locally, which may be a bit faster. If FALSE, use the XML file to get available data list.
Logical. If TRUE, force re-download of metadata. For Amazon S3 this queries the S3 bucket for the XML file it re-downloads. If FALSE, only update the available data list if it is older than 1 day.
A logical value indicating whether to suppress messages. Default is FALSE.