This function retrieves the data dictionary for the specified data directory.
spod_available_data_v2(
data_dir = spod_get_data_dir(),
check_local_files = FALSE,
quiet = FALSE
)A tibble with links, release dates of files in the data, dates of data coverage, local paths to files, and the download status.
character. The URL link to the data file.
POSIXct. The timestamp of when the file was published.
character. The file extension of the data file (e.g., 'tar', 'gz').
Date. The year and month of the data coverage, if available.
Date. The specific date of the data coverage, if available.
character. The local file path where the data is stored.
logical. Indicator of whether the data file has been downloaded locally. This is only available if check_local_files is TRUE.
The directory where the data is stored. Defaults to the value returned by spod_get_data_dir().
Whether to check if the local files exist. Defaults to FALSE.
A logical value indicating whether to suppress messages. Default is FALSE.