This function ensures that the necessary v1 raw data for zones files are downloaded and extracted from the specified data directory.
spod_download_zones_v1(
zones = c("districts", "dist", "distr", "distritos", "municipalities", "muni",
"municip", "municipios"),
data_dir = spod_get_data_dir(),
quiet = FALSE,
metadata = NULL
)A character string containing the path to the downloaded and extracted file.
The zones for which to download the data. Can be "districts" (or "dist", "distr", or the original Spanish "distritos") or "municipalities" (or "muni", "municip", or the original Spanish "municipios").
The directory where the data is stored.
Boolean flag to control the display of messages.
Optional metadata table returned by spod_available_data().