![[Experimental]](figures/lifecycle-experimental.svg?package=spanishoddata&version=0.2.2)
This function fetches the municipalities (for now this is the only option) geometries from the mapas-movilidad website and returns a sf object with the municipalities geometries. This is intended for use with the flows data retrieved by the spod_quick_get_od() function. An interactive web map with this data is available at https://mapas-movilidad.transportes.gob.es/. These municipality geometries only include Spanish municipalities (and not the NUTS3 regions in Portugal and France) and do not contain extra columns that you can get with the spod_get_zones() function. The function caches the retrieved geometries in memory of the current R session to reduce the number of requests to the mapas-movilidad website.
For detailed zone definitions and methodology, see
mitma_methodology_2020_v3spanishoddata for v1 data and
mitms_methodology_2022_v8spanishoddata for v2 data.